==> syncope-3.0.11-source-release.zip: syncope-3.0.11/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/dao/RealmDAO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.dao;

import java.util.List;
import java.util.regex.Pattern;
import org.apache.syncope.core.persistence.api.entity.ExternalResource;
import org.apache.syncope.core.persistence.api.entity.Implementation;
import org.apache.syncope.core.persistence.api.entity.Realm;
import org.apache.syncope.core.persistence.api.entity.policy.Policy;

public interface RealmDAO extends DAO<Realm> {

    Pattern NAME_PATTERN = Pattern.compile("^[A-Za-z0-9~]+");

    Pattern PATH_PATTERN = Pattern.compile("^(/[A-Za-z0-9~]+)+");

    Realm getRoot();

    Realm find(String key);

    Realm findByFullPath(String fullPath);

    List<Realm> findByName(String name);

    List<Realm> findByResource(ExternalResource resource);

    int countDescendants(String base, String keyword);

    List<Realm> findDescendants(String base, String keyword, int page, int itemsPerPage);

    List<String> findDescendants(String base, String prefix);
    
    <T extends Policy> List<Realm> findByPolicy(T policy);

    List<Realm> findByLogicActions(Implementation logicActions);

    List<Realm> findAncestors(Realm realm);

    List<Realm> findChildren(Realm realm);

    int count();

    List<String> findAllKeys(int page, int itemsPerPage);

    Realm save(Realm realm);

    void delete(Realm realm);
}

==> syncope-3.0.16-source-release.zip: syncope-3.0.16/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/dao/RealmDAO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.dao;

import java.util.List;
import java.util.Set;
import java.util.regex.Pattern;
import org.apache.syncope.core.persistence.api.entity.ExternalResource;
import org.apache.syncope.core.persistence.api.entity.Implementation;
import org.apache.syncope.core.persistence.api.entity.Realm;
import org.apache.syncope.core.persistence.api.entity.policy.Policy;

public interface RealmDAO extends DAO<Realm> {

    Pattern NAME_PATTERN = Pattern.compile("^[A-Za-z0-9~]+");

    Pattern PATH_PATTERN = Pattern.compile("^(/[A-Za-z0-9~]+)+");

    Realm getRoot();

    Realm find(String key);

    Realm findByFullPath(String fullPath);

    List<Realm> findByName(String name);

    List<Realm> findByResource(ExternalResource resource);

    int countDescendants(String base, String keyword);

    int countDescendants(Set<String> bases, String keyword);

    List<Realm> findDescendants(String base, String keyword, int page, int itemsPerPage);

    List<Realm> findDescendants(Set<String> bases, String keyword, int page, int itemsPerPage);

    List<String> findDescendants(String base, String prefix);

    <T extends Policy> List<Realm> findByPolicy(T policy);

    List<Realm> findByLogicActions(Implementation logicActions);

    List<Realm> findAncestors(Realm realm);

    List<Realm> findChildren(Realm realm);

    int count();

    List<String> findAllKeys(int page, int itemsPerPage);

    Realm save(Realm realm);

    void delete(Realm realm);
}
